@@ -6,8 +6,8 @@ from aiohttp import web
 from aiohttp.test_utils import TestClient
 
 
-async def post_handler(request: aiohttp.web.Request) -> aiohttp.web.Response:
-    """Handles the post method, inserting response prepared by tests."""
+async def handler(request: aiohttp.web.Request) -> aiohttp.web.Response:
+    """Handles the request, inserting response prepared by tests."""
     assert request.app["response"]
     response = request.app["response"].pop(0)
     return cast(aiohttp.web.Response, response)
@@ -19,7 +19,8 @@ def cli(
 ) -> TestClient:
     """Creates a fake aiohttp client."""
     app = web.Application()
-    app.router.add_post("/stream", post_handler)
+    app.router.add_get("/static", handler)
+    app.router.add_post("/stream", handler)
     app["response"] = []
     client = loop.run_until_complete(aiohttp_client(app))
     return cast(TestClient, client)
